class Dcs2restConfigsController < RxModule::ApplicationController

  model_data_store(Dcs2restConfig)

  def create
    @model = model_type.new(model_params)
    @model.add_new_interfaces_from_data(interface_configs_create_params)
    if @model.save
      render json: @model, status: :created, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def update
    interface_configs_update_params.each do |interface_type, interface_config_arr|
      interface_config_arr.each do |interface_config|
        interface_config.symbolize_keys!
        config_model = InterfaceConfig.find(interface_config[:id])
        config_model.update(x_status: interface_config[:x_status], data: interface_config[:data].to_json)
      end
    end

    if @model.update(model_params)
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def destroy
    if @model.destroy
      head :no_content
    else
      render json: @model.errors.full_messages, status: :conflict
    end
  end

  def default_config_json
    file = Rails.cache.fetch([self, :default_config_json]) do
      File.read("#{Rails.root}/public/DefaultInterfaceConfigs.json")
    end
    render json: file
  end

  def interface_config_examples_json
    file = Rails.cache.fetch([self, :interface_config_examples_json]) do
      File.read("#{Rails.root}/public/InterfaceConfigExamples.json")
    end
    render json: file
  end

  private

  def is_default_config?
    @model.name == Dcs2restConfig.default_name
  end

  def interface_configs_create_params
    # Filter out temp id that could have been injected
    p = JSON.parse(params.fetch(:dcs2rest_config).permit(:interface_configs)["interface_configs"])
    p.each do |config_type, arr|
      arr.each do |hash|
        hash.reject! {|k,v| k == 'id'}
      end
    end
    p
  end

  def interface_configs_update_params
    # Keep id that comes from the real models
    JSON.parse(params.fetch(:dcs2rest_config).permit(:interface_configs)["interface_configs"])
  end

  def model_params
    params.fetch(:dcs2rest_config).permit(:name, :machine_state_min, :machine_state_max, :error_min, :error_max, :job_state_min, :job_state_max, :process_parameter_min, :process_parameter_max, :maintenance_min, :maintenance_max, :calibration_min, :calibration_max, :event_min, :event_max, :created_at, :updated_at)
  end
end