import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Box, Accordion, AccordionSummary, AccordionDetails} from "@material-ui/core";
import {ExpandMore} from "@material-ui/icons";
import Typography from "@material-ui/core/Typography";
import {getInterfaceKeyForInterfaceType, InterfaceType} from '../../stores/InterfaceConfigStore';
import {useModelContext} from "@rx-suite/ui";

type InterfaceConfigExampleAccordionProps = {
    interfaceType: InterfaceType;
};

export const InterfaceConfigExampleAccordion: React.FunctionComponent<InterfaceConfigExampleAccordionProps> = observer(({interfaceType}) => {
    const model = useModelContext()

    if (!model.viewModel.interface_examples) {
        return null;
    }

    const interfaceKey = getInterfaceKeyForInterfaceType(interfaceType);
    const interfaceExample = model.viewModel.interface_examples[interfaceKey];

    return (
        <Box>
            <Accordion>
                <AccordionSummary expandIcon={<ExpandMore />}>
                    <Typography>{t`DCS Message Example`}</Typography>
                </AccordionSummary>
                <AccordionDetails>
                    <Typography component={'pre'}>
                        {interfaceExample.dcs}
                    </Typography>
                </AccordionDetails>
            </Accordion>
            <Accordion>
                <AccordionSummary expandIcon={<ExpandMore />}>
                    <Typography>{t`Corresponding XML`}</Typography>
                </AccordionSummary>
                <AccordionDetails>
                    <Typography component={'pre'}>
                        {interfaceExample.xml}
                    </Typography>
                </AccordionDetails>
            </Accordion>
        </Box>
    );
});
