import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Column} from "react-table";
import {BaseInterfaceConfigForm} from "./BaseInterfaceConfigForm";
import {useXStatusColumn} from "../useXStatusColumn";

type CalibrationInterfaceConfigFormProps = {
};

export const CalibrationInterfaceConfigForm: React.FunctionComponent<CalibrationInterfaceConfigFormProps> = observer(() => {
    const buildTableData = (arr: any[]) => {
        return arr.map((modelDatum) => {
            const dataJson = modelDatum.data;
            return {
                id: modelDatum.id,
                x_status: modelDatum.x_status,
                type: dataJson.type
            };
        });
    }

    const columns = [
        useXStatusColumn('calibration'),
        {
            Header: t`Type`,
            accessor: 'type',
            sortable: true
        }
    ] as Column[];

    return <BaseInterfaceConfigForm
        columns={columns}
        interfaceType={'CalibrationInterfaceConfig'}
        interfaceConfigKey={'calibration'}
        buildTableData={buildTableData}
        rangeKeys={{ min: 'calibration_min', max: 'calibration_max' }}
        defaultSorted={[{id: 'type', desc: false}]}
    />;
});
