import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Column} from "react-table";
import {BaseInterfaceConfigForm} from "./BaseInterfaceConfigForm";
import {useXStatusColumn} from "../useXStatusColumn";

type ErrorInterfaceConfigFormProps = {
};

const errortype_to_enum = ['Unknown', 'Info', 'Alarm', 'Error']
const status_to_enum = ['Raised', 'Acknowledge', 'Finished']

export const ErrorInterfaceConfigForm: React.FunctionComponent<ErrorInterfaceConfigFormProps> = observer(() => {
    const buildTableData = (arr: any[]) => {
        return arr.map((modelDatum) => {
            const dataJson = modelDatum.data;
            return {
                id: modelDatum.id,
                x_status: modelDatum.x_status,
                error_type: errortype_to_enum[dataJson.errortype],
                status: status_to_enum[dataJson.status]
            };
        });
    }

    const columns = [
        useXStatusColumn('error'),
        {
            Header: t`Error Type`,
            accessor: 'error_type',
            sortable: true
        },
        {
            Header: t`Status`,
            accessor: 'status',
            sortable: true
        }
    ] as Column[];


    return <BaseInterfaceConfigForm
        columns={columns}
        interfaceConfigKey={'error'}
        interfaceType={'ErrorInterfaceConfig'}
        buildTableData={buildTableData}
        rangeKeys={{ min: 'error_min', max: 'error_max' }}
        defaultSorted={[{id: 'error_type', desc: false}, {id: 'status', desc: false}]}
    />;
});
