import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Column} from "react-table";
import {BaseInterfaceConfigForm} from "./BaseInterfaceConfigForm";
import {useXStatusColumn} from "../useXStatusColumn";

type JobStateInterfaceConfigFormProps = {
};

export const JobStateInterfaceConfigForm: React.FunctionComponent<JobStateInterfaceConfigFormProps> = observer(() => {
    const buildTableData = (arr: any[]) => {
        return arr.map((modelDatum) => {
            const dataJson = modelDatum.data;
            return {
                id: modelDatum.id,
                x_status: modelDatum.x_status,
                job_state: dataJson.state,
                scrap: dataJson.scrap
            };
        });
    }

    const columns = [
        useXStatusColumn('job_state'),
        {
            Header: t`Job State`,
            accessor: 'job_state',
            sortable: true
        },
        {
            Header: t`Scrap`,
            accessor: 'scrap',
            sortable: true
        }
    ] as Column[];


    return <BaseInterfaceConfigForm
        columns={columns}
        interfaceType={'JobStateInterfaceConfig'}
        interfaceConfigKey={'job_state'}
        buildTableData={buildTableData}
        rangeKeys={{ min: 'job_state_min', max: 'job_state_max' }}
        defaultSorted={[{id: 'job_state', desc: false}, {id: 'scrap', desc: false}]}
    />;
});
