import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Column} from "react-table";
import {BaseInterfaceConfigForm} from "./BaseInterfaceConfigForm";
import {useXStatusColumn} from "../useXStatusColumn";

type MachineStateInterfaceConfigFormProps = {};

export const MachineStateInterfaceConfigForm: React.FunctionComponent<MachineStateInterfaceConfigFormProps> = observer(() => {
    const buildTableData = (arr: any[]) => {
        return arr.map((modelDatum) => {
            const dataJson = modelDatum.data;
            return {
                id: modelDatum.id,
                x_status: modelDatum.x_status,
                machine_state: dataJson.state
            };
        });
    }

    const columns = [
        useXStatusColumn('machine_state'),
        {
            Header: t`Machine State`,
            accessor: 'machine_state',
            sortable: true
        }
    ] as Column[];

    return <BaseInterfaceConfigForm
        columns={columns}
        interfaceConfigKey={'machine_state'}
        interfaceType={'MachineStateInterfaceConfig'}
        buildTableData={buildTableData}
        rangeKeys={{ min: 'machine_state_min', max: 'machine_state_max' }}
        defaultSorted={[{id: 'machine_state', desc: false}]}
    />;
});
