import * as React from 'react';
import {BreadModel, BreadModelListBadge, makeColumn} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {Dcs2restConfigStore} from "../../stores/Dcs2restConfigStore";
import {Dcs2restConfigForm} from "./Dcs2restConfigForm";
import {MachinePickerStore} from "@rx-suite/stores";
import {LinearProgress} from "@material-ui/core";
import {useMemo} from "react";
import {observer} from "mobx-react-lite";

export const Dcs2restConfigsBreadModel = observer(() => {
    MachinePickerStore.getAll();

    const columns = useMemo(() => {
        return [
            makeColumn('name', t`Name`, "string"),
            {
                Header: 'Used By',
                accessor: 'connected_machine_ids',
                Cell: (cellInfo: {value: string[]}) => {
                    return MachinePickerStore.models.filter((machine) => {
                        return cellInfo.value.includes(machine.getId());
                    }).map((machine) => {
                        return <BreadModelListBadge text={machine.extended_name}/>
                    })
                }
            }
        ]
    }, [MachinePickerStore.models])

    if(MachinePickerStore.isLoading) {
        return <LinearProgress/>
    }

    return (
        <BreadModel store={Dcs2restConfigStore} Form={Dcs2restConfigForm} columns={columns}/>
    )
});