import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, PaddedPaper} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {TabsContainer} from "../../components/generic/TabsContainer";
import {DcsConfigModel} from "../../stores/DcsConfigStore";
import {DcsConfigTab} from "../../components/dcs_config/DcsConfigTab";
import {DcsTraceTab} from "../../components/dcs_config/DcsTraceTab";
import {DcsTestTab} from "../../components/dcs_config/DcsTestTab";

type DcsConfigFormProps = {
    model: DcsConfigModel
}& Omit<FormProps, 'model'>

export const DcsConnectionForm: React.FunctionComponent<DcsConfigFormProps> = observer(({model}) => {
    return (
        <PaddedPaper>
            <TabsContainer
                    tabs={
                        [
                            {
                                label: t`Configuration`,
                                component: <DcsConfigTab model={model}/>,
                                disabled: false,
                                defaultTab: true
                            },
                            {
                                label: t`Test`,
                                component: <DcsTestTab model={model}/>,
                                disabled: model.isNew,
                                defaultTab: false
                            },
                            {
                                label: t`Traces`,
                                component: <DcsTraceTab model={model}/>,
                                disabled: model.isNew,
                                defaultTab: false
                            }
                        ]
                    }
                    variant="scrollable"
            />
        </PaddedPaper>
    )
});
