import * as React from "react";
import {FormProps, makeColumn, makeFormattedDateTimeColumn, ModelTable} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Dcs2restTraceModel, Dcs2restTraceStore} from "../../stores/Dcs2restTraceStore";
import {useCallback, useMemo, useState} from "react";
import {t} from "@lingui/macro";
import {Dcs2restTraceDialog} from "../../components/machine_configs/Dcs2restTraceDialog";
import {StatusIndicator} from "../../components/generic/StatusIndicator";
import {IconButton} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faFileSearch} from "@rx-suite/pro-solid-svg-icons";
import {IconProp} from "@fortawesome/fontawesome-svg-core";

export const MachineConfigTraces: React.FunctionComponent<FormProps> = observer(({model}) => {
    const [open, setOpen] = useState(false);
    const [dialogModel, setDialogModel] = useState<Dcs2restTraceModel | null>(null);

    const handleDialogOpen = useCallback((model: Dcs2restTraceModel) => {
        setDialogModel(model);
        setOpen(true);
    }, [])

    const handleClose = useCallback(() => {
        setOpen(false);
    }, [])

    const columns = useMemo(() => {
        return [
            makeFormattedDateTimeColumn('time', t`Time`, 'dateTime'),
            makeColumn('targeted_endpoint', t`Endpoint`, 'string'),
            {
                Header: t`Successful?`,
                id: 'success',
                accessor: (model: Dcs2restTraceModel) => model,
                Cell: (cellInfo: { value: Dcs2restTraceModel }) => {
                    return <StatusIndicator success={cellInfo.value.success}/>
                }
            }
        ]
    }, [])

    return <React.Fragment>
        <ModelTable
            store={Dcs2restTraceStore}
            columns={columns}
            customActions={(model) =>
                <IconButton onClick={() => handleDialogOpen(model as Dcs2restTraceModel)}>
                    <FontAwesomeIcon icon={faFileSearch as IconProp}/>
                </IconButton>
            }
            actionColumnWidth={110}
            defaultFiltered={[{id: 'machine_config_id', value: model.id}]}
            suppressWrapper
        />
        <Dcs2restTraceDialog model={dialogModel} open={open} handleClose={handleClose}/>
    </React.Fragment>
})