import {BreadModel, makeColumn} from "@rx-suite/ui";
import * as React from "react";
import {MachineConfigModel, MachineConfigStore} from "../../stores/MachineConfigStore";
import {t} from "@lingui/macro";
import {LinearProgress} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {Dcs2restConfigModel, Dcs2restConfigStore} from "../../stores/Dcs2restConfigStore";
import {MachineConfigPage} from "./MachineConfigPage";
import {useMemo} from "react";
import {MachinePickerModel, MachinePickerStore} from "@rx-suite/stores";

export const MachineConfigsBreadModel = observer(() => {
    MachinePickerStore.getAll();
    Dcs2restConfigStore.getAll();

    const columns = useMemo(() => {
        return [
            {
                Header: t`Machine Name`,
                accessor: (model: MachineConfigModel) => model,
                id: 'rx_data_machine_id',
                Cell: (cellInfo: {value: MachineConfigModel}) => {
                    const machine = MachinePickerStore.models
                            .find((machine: MachinePickerModel) => machine.id === cellInfo.value.rx_data_machine_id) as MachinePickerModel;

                    if(!machine){
                        return t`Unknown`;
                    }

                    return machine.extended_name;
                }
            },
            makeColumn('ip_address', 'Ip Address', 'string'),
            {
                Header: t`Translation Interface`,
                accessor: (model: MachineConfigModel) => model,
                id: 'translation_interface',
                Cell: (cellInfo: {value: MachineConfigModel}) => {
                    const config = Dcs2restConfigStore.models
                        .find((config) => config.id === cellInfo.value.dcs2rest_config_id) as Dcs2restConfigModel;

                    if(!config){
                        return t`Unknown`;
                    }

                    return config.name;
                }
            }
        ]
    }, [])

    if(MachinePickerStore.isLoading || Dcs2restConfigStore.isLoading) {
        return <LinearProgress/>
    }

    return (
        <BreadModel store={MachineConfigStore} Form={MachineConfigPage} columns={columns}/>
    )
})
