import React from "react";
import {CheckboxField, ModelForm, ModelInput, ServiceControllerButton} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {LinearProgress} from "@material-ui/core";
import {Dcs2restSettingModel, Dcs2restSettingStore} from "../../stores/Dcs2restSettingStore";
import Typography from "@material-ui/core/Typography";

export const Dcs2RestSettingForm: React.FunctionComponent = observer(() => {
    const model = Dcs2restSettingStore.selectedModel as Dcs2restSettingModel;

    if (!model) {
        return <LinearProgress color={'secondary'}/>
    }

    return (
        <ModelForm model={model} suppressImportExport suppressMakeCopy>
            <ServiceControllerButton name='Dcs2Rest Server' online={model.server_online} enabled={model.enable_server} startAction={model.startDcs2RestServer} stopAction={model.stopDcs2RestServer}/>
            <Typography variant={'h5'}>{t`Settings`}</Typography>
            <div>
                <CheckboxField name={'enable_server'} label={t`Enable Dcs2Rest server`} color={"secondary"} onChange={model.handleCheckboxChange} checked={model.viewModel.enable_server}/>
                <div>
                    <Typography variant={'caption'}>{t`Note: changes must be saved before the server can be started.`}</Typography>
                </div>
            </div>
            <ModelInput name={'port'} type={'number'}/>
            <ModelInput name={'max_dcs_trace_count'}
                        type={'number'}
                        hint={
                            {
                                title: t`Max DCS trace count`,
                                text: t`Maximum amount of trace logs that are kept per DCS connection, older traces are deleted first.`
                            }
                        }
            />
        </ModelForm>
    )
});