import React from "react";
import {dataStorePermission, PasswordResetForm, RouteDefinition} from "@rx-suite/ui";
import {DcsConfigStore} from "./stores/DcsConfigStore";
import {faNetworkWired} from "@rx-suite/pro-solid-svg-icons";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {SettingStore} from "./stores/SettingStore";
import {Settings, SubdirectoryArrowRight, Transform} from "@material-ui/icons";
import {DcsConnectionsBreadModel} from "./pages/dcs_connections/DcsConnectionsBreadModel";
import {Dcs2restConfigStore} from "./stores/Dcs2restConfigStore";
import { Dcs2restConfigsBreadModel } from "./pages/dcs2rest_configs/Dcs2restConfigsBreadModel";
import {MachineConfigsBreadModel} from "./pages/machine_configs/MachineConfigsBreadModel";
import {DcsSettingForm} from "./pages/settings/DcsSettingForm";
import {Dcs2RestSettingForm} from "./pages/settings/Dcs2RestSettingForm";

export const routes: RouteDefinition[] = [
    {
        label: "DCS Connections",
        to: "/dcs_connections",
        exact: false,
        permission: dataStorePermission(DcsConfigStore),
        Component: DcsConnectionsBreadModel,
        Icon: () => <FontAwesomeIcon icon={faNetworkWired} style={{height: '22px', width: '22px'}}/>
    },
    {
        label: "DCS2REST",
        to: "/dcs2rest/machine_config",
        exact: false,
        permission: dataStorePermission(Dcs2restConfigStore),
        Component: MachineConfigsBreadModel,
        Icon: Transform
    },
    {
        label: "Settings",
        to: "/settings",
        exact: true,
        permission: dataStorePermission(SettingStore),
        Icon: Settings,
        children: [
            {
                label: "DCS",
                to: "/dcs",
                exact: true,
                permission: dataStorePermission(SettingStore),
                Component: DcsSettingForm,
                Icon: () => <FontAwesomeIcon icon={faNetworkWired} style={{height: '22px', width: '22px'}}/>
            },
            {
                label: "DCS2REST",
                to: "/dcs2rest",
                exact: true,
                permission: dataStorePermission(SettingStore),
                Component: Dcs2RestSettingForm,
                Icon: Transform,
                children: [
                    {
                        label: "Translation Interfaces",
                        to: "/interfaces",
                        exact: false,
                        permission: dataStorePermission(Dcs2restConfigStore),
                        Component: Dcs2restConfigsBreadModel,
                        Icon: SubdirectoryArrowRight
                    }
                ]
            }
        ]
    },
    {
        to: "/password_reset/:user/:token",
        exact: false,
        Component: PasswordResetForm,
    }
];
