import {attribute, DataStore, Model, model} from '@rx-suite/data';
import {computed} from "mobx";

@model({
    transportLayer: "/api/dcs_traces",
    permissionTarget: "DcsTrace",
})

export class DcsTraceModel extends Model {
    @attribute()
    id: number = 0;

    @attribute()
    job_number: string = '';

    @attribute()
    raw_data: string | null = null;

    @attribute()
    parsed_data: string | null = null;

    @attribute()
    last_error: string | null  = null;

    @attribute()
    created_at: Date = new Date;

    @computed
    get successful(){
        return this.last_error === null
    }

    @computed
    get hasData(){
        return this.raw_data !== null
    }

    @computed
    get resolveParsedData(): TagData {
        if(!this.parsed_data){
            return {left: null, right: null};
        }

        return JSON.parse(this.parsed_data);
    }

    @computed
    get resolveErrorData(): ErrorData | null {
        if(!this.last_error){
            return null;
        }

        return JSON.parse(this.last_error);
    }

    constructor() {
        super();
        super.setup();
    }
}

export const DcsTraceStore = DcsTraceModel.store as DataStore<DcsTraceModel>;

export type TagData = {
    [name: string]: TagHash | null;
}

type TagHash = {
    [name: string]: string;
}

export type ErrorData = {
    message: string;
    timeout: boolean;
    failToFetch: boolean;
    jobDoesNotExist: boolean;
}