import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {InterfaceConfigKeys} from "./Dcs2restConfigStore";

export type InterfaceType = 'MachineStateInterfaceConfig'
    | 'ErrorInterfaceConfig'
    | 'JobStateInterfaceConfig'
    | 'ProcessParameterInterfaceConfig'
    | 'MaintenanceInterfaceConfig'
    | 'CalibrationInterfaceConfig'
    | 'EventInterfaceConfig'
;

type SessionType = 'MNT' | 'INF' | 'INS';

@model({
    transportLayer: "/api/interface_config",
    permissionTarget: "InterfaceConfig",
    routingInfo: {
        create: '/interface_config/create',
        read: '/interface_config/:id/edit',
        update: '/interface_config/:id/edit'
    }
})
export class InterfaceConfigModel extends Model {
    @attribute({
        label: t`Type`,
        validation: yup.string()
    })
    type: InterfaceType = 'MachineStateInterfaceConfig';

    @attribute({
        label: t`Status X`,
        validation: yup.number().min(0)
    })
    x_status: number = 0;

    @attribute({
        label: t`Data`,
        validation: yup.string()
    })
    data: string = '{}';

    constructor() {
        super();
        super.setup();
    }
}

export function getSessionTypeForInterfaceType(interfaceType: InterfaceType): SessionType {

    return {
        MachineStateInterfaceConfig: 'MNT',
        ErrorInterfaceConfig: 'MNT',
        JobStateInterfaceConfig: 'INF',
        ProcessParameterInterfaceConfig: 'INS',
        MaintenanceInterfaceConfig: 'MNT',
        CalibrationInterfaceConfig: 'MNT',
        EventInterfaceConfig: 'INF'
    }[interfaceType] as SessionType;
}

export function getInterfaceKeyForInterfaceType(interfaceType: InterfaceType): InterfaceConfigKeys {

    return {
        MachineStateInterfaceConfig: 'machine_state',
        ErrorInterfaceConfig: 'error',
        JobStateInterfaceConfig: 'job_state',
        ProcessParameterInterfaceConfig: 'process_parameter',
        MaintenanceInterfaceConfig: 'maintenance',
        CalibrationInterfaceConfig: 'calibration',
        EventInterfaceConfig: 'event'
    }[interfaceType] as InterfaceConfigKeys;
}

export const InterfaceConfigStore = InterfaceConfigModel.store as DataStore<InterfaceConfigModel>;
