class JobStateInterfaceConfig < InterfaceConfig

  concerning :DcsToXml do
    def dcs_to_xml(dcs_data)
      xml_arr = []

      # Check number of xstatus lines first
      xstatus_messages = dcs_data.select {|msg| msg.include? 'XSTATUS='}

      if xstatus_messages.count > 1
        # Here we would usually do add_data_arguments, but since we have multiple xstatus lines, we need to add data
        # from multiple interface configs.
        xstatuses = xstatus_messages.map { |xstatus_message| xstatus_message.split('=')[1].split(';')[1] }

        xstatuses.each_with_index do |xstatus, index|
          interface = dcs2rest_config.interface_configs.where(x_status: xstatus, type: type).first

          arguments = generate_base_arguments(dcs_data, interface)

          # since there's at least 2 xstatus, we get the lensside from the xstatus tag
          arguments.merge!({lensside: xstatus_messages[index].split('=')[1][0]})
          xml = build_xml(arguments)
          xml_arr << add_extra_xml_nodes(xml, dcs_data, xstatus_messages[index])
        end
      else
        arguments = generate_base_arguments(dcs_data)

        arguments.merge!({lensside: get_lensside_single_xstatus(dcs_data)})
        xml = build_xml(arguments)
        xml_arr << add_extra_xml_nodes(xml, dcs_data, xstatus_messages[0])
      end
      xml_arr
    end

    def generate_base_arguments(dcs_data, interface = nil)
      resolve_interface = interface || self
      arguments = DcsMessageParser.process_arguments(arguments_to_read, dcs_data)
      arguments.merge! JSON.parse(resolve_interface.data)
      arguments
    end

    def get_lensside_single_xstatus(dcs_data)
      line = dcs_data.find {|msg| msg.include?('DO') || msg.include?('_LENSSIDE')}
      return line.split('=')[1] if line

      dcs_data.find {|msg| msg.include? 'XSTATUS='}.split('=')[1][0]
    end

    def arguments_to_read
      [
        make_parameter_config_hash('job', 'JOB', '=', 1, true)
      ]
    end

    def build_xml(args_hash)
      Nokogiri::XML::Builder.with(base_xml) do |xml|
        xml.jobstate('xmlns' => xmlns) {
          args_hash.each do |k, v|
            xml.method_missing(k, v)
          end
        }
      end.doc
    end

    def add_extra_xml_nodes(xml, data, xstatus_line)
      doc = Nokogiri::XML(xml.to_xml)
      job_state = doc.root
      job_state.at('scrap').content = job_state.at('scrap').content == 'Y' ? 'true' : 'false'
      if job_state.at('scrap').content == 'true'
        scrap_reason_string = xstatus_line.split(';')[2]

        return doc if scrap_reason_string.empty?

        scrap_reason = Nokogiri::XML::Node.new('scrapReason', doc)
        scrap_reason.content = scrap_reason_string
        job_state.first_element_child.before(scrap_reason)
      else
        comment_string = xstatus_line.split(';')[2]

        comment = Nokogiri::XML::Node.new('comment', doc)
        comment.content = comment_string
        job_state.first_element_child.before(comment)
      end
      doc
    end

    def endpoint
      'connector/satisloh/jobstate/1.0/add'
    end

    def xmlns
      'http://www.software4production.com/connector/satisloh/jobstate_1_0'
    end
  end
end
