class ProcessParameterInterfaceConfig < InterfaceConfig

  concerning :DcsToXml do
    def arguments_to_read
      [
        make_parameter_config_hash('job', 'JOB', '=', 1, true)
      ]
    end

    def dcs_to_xml(dcs_data)
      # This Interface creates an xml for both sides and sends both separately
      arguments = DcsMessageParser.process_arguments(self.arguments_to_read, dcs_data)
      lens_side = get_lens_side_from_data(dcs_data)
      xml_arr = []
      if ['R', 'B'].include? lens_side
        xml_arr << build_xml(arguments, dcs_data, 'R')
      end

      if ['L', 'B'].include? lens_side
        xml_arr << build_xml(arguments, dcs_data, 'L')
      end
      xml_arr
    end

    def get_lens_side_from_data(data)
      data.find {|message| message.include? 'DO'}.split('=')[1]
    end

    def build_xml(args_hash, messages, side)
      Nokogiri::XML::Builder.with(base_xml) do |xml|
        xml.processparameter('xmlns' => xmlns) {
          args_hash.each do |k, v|
            xml.method_missing(k, v)
          end
          xml.method_missing('lensside', side)
          param_messages = messages.filter {|message| (message =~ /^(JOB|DO|REQ)/).nil?}
          xml.params {
            param_messages.each do |param_message|
              split_message = param_message.split('=')
              tag = split_message[0]
              value = split_message[1].split(';')[side_to_param_side[side]]
              xml.param('name' => tag, 'value' => value) unless value.empty?
            end
          }
        }
      end
    end

    def side_to_param_side
      {
        'R' => 0,
        'L' => 1
      }
    end

    def endpoint
      'connector/satisloh/processparameter/1.1/add'
    end

    def xmlns
      'http://www.software4production.com/connector/satisloh/processparameter_1_1'
    end
  end
end
