class MachineConfig < ApplicationRecord
  include RxModule::LatestAssociatedModel

  belongs_to :dcs2rest_config
  has_many :dcs2rest_traces

  class << self
    def get_all_non_top_x_dcs2rest_traces_per_machine_config(limit)
      Dcs2restTrace.where.not(id: Dcs2restTrace.from(
        MachineConfig.latest_records_per_foreign_key(Dcs2restTrace,
                                                     foreign_key_column: :machine_config_id,
                                                     base_class_key_column: :id,
                                                     time_column: :time,
                                                     limit: limit)
      ).select(:id))
    end
  end

  def create_error_trace(data, time, error)
    dcs2rest_traces.create!({raw_data: data.to_json, last_error: error, time: time}) if keep_call_trace
  end

  def create_trace(data, time, xml, endpoint)
    if xml.is_a? Array
      xml = xml.reduce('') {|acc, x| acc << x.to_xml}
    else
      xml = xml.to_xml
    end
    dcs2rest_traces.create!({ raw_data: data.to_json, time: time, generated_payload: xml, targeted_endpoint: endpoint}) if keep_call_trace
  end
end